@@ -6,7 +6,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-0.33
+0.34
 
 =head1 SYNOPSIS
 
@@ -161,8 +161,9 @@ use File::Basename qw( basename );
 use File::Path ();
 use File::Spec ();
 use constant CACHE_ASSETS => $ENV{MOJO_ASSETPACK_NO_CACHE} ? 0 : 1;
+use constant DEBUG => $ENV{MOJO_ASSETPACK_DEBUG} || 0;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 =head1 ATTRIBUTES
 
@@ -302,6 +303,34 @@ sub get {
   }
 }
 
+=head2 preprocessor
+
+  $self = $self->preprocessor($name => \%args);
+
+Use this method to manually register a preprocessor.
+
+See L<Mojolicious::Plugin::AssetPack::Preprocessor::Browserify/SYNOPSIS>
+for example usage.
+
+=cut
+
+sub preprocessor {
+  my ($self, $name, $args) = @_;
+  my $class = $name =~ /::/ ? $name : "Mojolicious::Plugin::AssetPack::Preprocessor::$name";
+  my $preprocessor;
+
+  $args->{extensions} or die "Usage: \$self->preprocessor(\$name => {extensions => [...]})";
+  eval "require $class;1" or die "Could not load $class: $@\n";
+  $preprocessor = $class->new($args);
+
+  for my $ext (@{$args->{extensions}}) {
+    warn "[ASSETPACK] Adding $class preprocessor.\n" if DEBUG;
+    $self->preprocessors->on($ext => $preprocessor);
+  }
+
+  return $self;
+}
+
 =head2 process
 
   $self->process($moniker => @files);
@@ -507,8 +536,8 @@ FILE:
       $data->{ext}  = $1 if $data->{path} =~ /\.(\w+)$/;
     }
     elsif (my $asset = $self->{static}->file($file)) {
-      $data->{path} = $asset->path;
-      $data->{body} = slurp $asset->path;
+      $data->{path} = $asset->can('path') ? $asset->path : $file;
+      $data->{body} = $asset->slurp;
       $data->{ext}  = $1 if $data->{path} =~ /\.(\w+)$/;
     }
     else {
